package me.unurled.sacredrealms.sr.gui.attributes;

import static me.unurled.sacredrealms.sr.utils.SRPlayerUtils.syncSRToPlayer;
import static me.unurled.sacredrealms.sr.utils.component.Component.comp;

import me.unurled.sacredrealms.sr.Manager;
import me.unurled.sacredrealms.sr.components.attributes.Attribute;
import me.unurled.sacredrealms.sr.components.player.PlayerManager;
import me.unurled.sacredrealms.sr.components.player.SRPlayer;
import org.bukkit.Material;
import org.bukkit.entity.Player;
import org.bukkit.event.inventory.ClickType;
import org.jetbrains.annotations.NotNull;
import xyz.xenondevs.invui.Click;
import xyz.xenondevs.invui.item.AbstractItem;
import xyz.xenondevs.invui.item.ItemBuilder;
import xyz.xenondevs.invui.item.ItemProvider;

public class AttributeItem extends AbstractItem {

  private final Attribute attribute;

  private final Player targetPlayer;

  public AttributeItem(Attribute attribute, Player target) {
    this.attribute = attribute;
    this.targetPlayer = target;
  }

  @Override
  public @NotNull ItemProvider getItemProvider(@NotNull Player viewer) {
    double value = 0;

    if (targetPlayer != null) {
      PlayerManager playerManager = Manager.getInstance(PlayerManager.class);
      SRPlayer sp = playerManager.getPlayer(targetPlayer.getUniqueId());
      if (sp != null) value = sp.getAttribute(attribute);
    }

    ItemBuilder ip =
        switch (attribute) {
          case STRENGTH -> new ItemBuilder(Material.IRON_SWORD).setCustomName("Strength " + value);
          case AGILITY -> new ItemBuilder(Material.BOW).setCustomName("Agility " + value);
          case MANA -> new ItemBuilder(Material.ENCHANTING_TABLE).setCustomName("Mana " + value);
          case HEALTH -> new ItemBuilder(Material.GOLDEN_APPLE).setCustomName("Health " + value);
          case LUCK ->
              new ItemBuilder(Material.ENCHANTED_GOLDEN_APPLE).setCustomName("Luck " + value);
          case DEFENSE -> new ItemBuilder(Material.SHIELD).setCustomName("Defense " + value);
          case CHARISMA -> new ItemBuilder(Material.PLAYER_HEAD).setCustomName("Charisma " + value);
        };

    ip.addLoreLines(comp("<green><b>+1</b> Left Click to increase"));
    ip.addLoreLines(comp("<red><b>-1</b> Right Click to decrease"));
    ip.addLoreLines(comp("<gray>Shift + Left Click to increase by 10"));
    ip.addLoreLines(comp("<gray>Shift + Right Click to decrease by 10"));

    return ip;
  }

  @Override
  public void handleClick(
      @NotNull ClickType clickType, @NotNull Player player, @NotNull Click click) {

    if (targetPlayer != null) {
      PlayerManager playerManager = Manager.getInstance(PlayerManager.class);
      SRPlayer sp = playerManager.getPlayer(targetPlayer.getUniqueId());
      if (sp != null) {
        if (clickType == ClickType.LEFT) {
          sp.setAttribute(attribute, sp.getAttribute(attribute) + 1);
        } else if (clickType == ClickType.RIGHT) {
          sp.setAttribute(attribute, sp.getAttribute(attribute) - 1);
        } else if (clickType == ClickType.SHIFT_LEFT) {
          sp.setAttribute(attribute, sp.getAttribute(attribute) + 10);
        } else if (clickType == ClickType.SHIFT_RIGHT) {
          sp.setAttribute(attribute, sp.getAttribute(attribute) - 10);
        }
        playerManager.savePlayer(sp);
        // update player
        syncSRToPlayer(sp, targetPlayer);
        notifyWindows();
      }
    }
  }
}
