package me.unurled.sacredrealms.sr.utils.component;

import java.util.List;
import net.kyori.adventure.audience.Audience;
import net.kyori.adventure.text.TextComponent;
import net.kyori.adventure.text.TranslatableComponent;
import net.kyori.adventure.text.minimessage.MiniMessage;
import org.bukkit.entity.Player;
import org.jetbrains.annotations.Contract;
import org.jetbrains.annotations.NotNull;

/** Utility class for working with components. */
public class Component {
  private static MiniMessage miniMessage;

  private Component() {}

  /**
   * Converts a string to a MiniMessage component.
   *
   * @param msg the string to convert
   * @return the MiniMessage component
   */
  public static net.kyori.adventure.text.@NotNull Component comp(String msg) {
    if (miniMessage == null) {
      miniMessage = MiniMessage.miniMessage();
    }
    return miniMessage.deserialize(msg);
  }

  /**
   * Converts a string to a TextComponent.
   *
   * @param msg the string to convert
   * @return the TextComponent
   */
  public static net.kyori.adventure.text.@NotNull TextComponent textComp(String msg) {
    if (miniMessage == null) {
      miniMessage = MiniMessage.miniMessage();
    }
    return (TextComponent) miniMessage.deserialize(msg);
  }

  /**
   * Converts a list of strings to a list of MiniMessage components.
   *
   * @param list the list of strings to convert
   * @return the list of MiniMessage components
   */
  public static List<net.kyori.adventure.text.Component> fromStringList(
      @NotNull List<String> list) {
    return list.stream().map(Component::comp).toList();
  }

  /**
   * Gets an audience for a player.
   *
   * @param player the player
   * @return the audience
   */
  @Contract(pure = true)
  public static @NotNull Audience audience(Player player) {
    return Audience.audience(player);
  }

  /**
   * Translates using the key and arguments.
   *
   * @param key the key
   * @param args the arguments
   * @return the translated string
   */
  @Contract(value = "_, _ -> new", pure = true)
  public static @NotNull TranslatableComponent translate(String key, TextComponent... args) {
    return net.kyori.adventure.text.Component.translatable(key, args);
  }
}
